campaign_response = {
    "actions": [
        {
            "type": "list",
            "title": "Here are some of the people:",
            "values": [
                {
                    "name": "John Doe",
                    "email": "johndoe@example.com",
                    "phone_number": "1234567890",
                },
                {
                    "name": "John Doe 2",
                    "email": "johndoe2@example.com",
                    "phone_number": "1234567891",
                },
            ],
        },
        {
            "type": "email_sequence_draft",
            "title": "Here is the draft",
            "subject": "Exclusive Christmas Offer: 15% Off until Jan 2, 2024!",
            "content": "Celebrate this season with our exclusive Christmas offer! Get ahead in 2024 by enjoying a 15% discount on [Your Product/Service]. Embrace the festive spirit and make the most of this limited-time offer. Act before Jan 2, 2024, to avail yourself of this special discount",
            "sequence_id": "140bb6d6-1c1d-4129-904a-2bb5e0f573d2",
        },
    ]
}

company_response = {
    "actions": [
        {
            "type": "list",
            "title": "Here are some of the companies:",
            "values": [
                {
                    "name": "Company A",
                    "email": "zz@not.an.email.com",
                    "linkedin": "https://www.linkedin.com/company/company-a",
                },
                {
                    "name": "Company B",
                    "email": "bb@not.an.email.com",
                    "linkedin": "https://www.linkedin.com/company/company-b",
                },
            ],
        }
    ]
}

people_response = {
    "actions": [
        {
            "type": "list",
            "title": "Here are some of the people:",
            "values": [
                {
                    "name": "Keerthi",
                    "email": "keerthi@not.an.email.com",
                    "phone_number": "1234567890",
                },
                {
                    "name": "Eva",
                    "email": "eva@not.an.email.com",
                    "phone_number": "1234567891",
                },
            ],
        }
    ]
}
